Module: RailsAiContext::Serializers::TestCommandDetection

Included in:
ClaudeSerializer, CopilotSerializer, MarkdownSerializer, OpencodeSerializer
Defined in:
lib/rails_ai_context/serializers/test_command_detection.rb

Overview

Shared helper for detecting the correct test command from introspection data. Include in any serializer that needs to output a test command.