Exception: RailsAiContext::BootManager::BootTimeoutError
- Inherits:
-
BootError
- Object
- StandardError
- BootError
- RailsAiContext::BootManager::BootTimeoutError
- Defined in:
- lib/rails_ai_context/boot_manager.rb
Overview
A dedicated subclass for the timeout case lets callers (the CLI's failure branch) distinguish "boot never finished" from other boot failures without parsing error message text.